﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using MonoSoftware.MonoX.Repositories;
using MonoSoftware.MonoX.Utilities;
using MonoSoftware.MonoX.DAL.EntityClasses;
using MonoSoftware.Core;
using MonoSoftware.Web.DataManager;
using MonoSoftware.MonoX.DAL.HelperClasses;

namespace MonoSoftware.MonoX.ModuleGallery
{
    public partial class CustomMembershipEditor : MonoSoftware.MonoX.ModuleGallery.MembershipEditor
    {
        #region Properties

        /// <summary>
        /// Gets the value if module is in edit mode.
        /// </summary>
        public bool EditMode
        {
            get
            {
                return !String.IsNullOrEmpty(UserName) && Page.User.Identity.IsAuthenticated;
            }
        }
        private DataManager _dataManager;
        /// <summary>
        /// Gets or sets data manager.
        /// </summary>
        private DataManager DataManager
        {
            get
            {
                if (_dataManager == null)
                    _dataManager = new DataManager();
                return _dataManager;
            }
            set { _dataManager = value; }
        }
        private UserProfileEntity _userProfile = null;
        private UserProfileEntity UserProfile
        {
            get 
            {
                if (_userProfile == null)
                    _userProfile = UserProfileRepository.GetInstance().GetUserProfile(SecurityUtility.GetUserId());
                return _userProfile;
            }
            set { _userProfile = value; }
        }

        #endregion

        #region Page Events

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);

            DataManager.IsPreviewMode = false;
            DataManager.DataBindings.Add(txtFirstName, UserProfileFields.FirstName.Name);
            DataManager.DataBindings.Add(txtLastName, UserProfileFields.LastName.Name);

            this.AccountCreated += new MembershipModuleEvent(TestMembershipEditor_AccountCreated);
            this.AccountUpdated += new MembershipModuleEvent(TestMembershipEditor_AccountUpdated);
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
            if (EditMode && !Page.IsPostBack)
            {
                DataManager.TransferDataToControls(UserProfile);
            }
        }

        #endregion

        #region Event Handler Methods

        void TestMembershipEditor_AccountUpdated(object sender, MembershipModuleEventArgs e)
        {
            DataManager.TransferDataFromControls(UserProfile);

            BaseMonoXRepository.GetInstance().SaveEntity(UserProfile);
        }

        void TestMembershipEditor_AccountCreated(object sender, MembershipModuleEventArgs e)
        {
            UserProfile = UserProfileRepository.GetInstance().GetUserProfile((Guid)(e.MembershipUser.ProviderUserKey));
            DataManager.TransferDataFromControls(UserProfile);

            BaseMonoXRepository.GetInstance().SaveEntity(UserProfile);
        }

        #endregion



    }
}